# Original authors: don
# $Revision: $


=pod

=head1 NAME

Pod::POM::View::Restructured::Changes - List of major changes in Pod::POM::View::Restructured

=head1 CHANGES

=head2 Version 0.02

=over 4

=item Added documentation for changes.

=item Added C<callbacks> option.

=item Added C<no_toc> option.

=item Fixed bug encountered when no index is being output.

=item Fixed section links.

=back


=head2 Version 0.01

=over 4

=item Initial release.

=back




=cut

1;
